# EVO-SPOTIS
This is Python 3 library for multi-criteria decision analysis with decision-maker preference identification.

# Installation
Downloading and installation can be done using pip
```
pip install evo-spotis
```
